/********************************************************************
 File:  main.m
 
 Created: 5/6/10
 Modified: 7/15/10
 
 Author: Yunfeng Zhang
 Cognitive Modeling and Eye Tracking Lab
 CIS Department
 University of Oregon
 
 Funded by the Office of Naval Research & National Science Foundation.
 Primary Investigator: Anthony Hornof.
 
 Copyright (c) 2010 by the University of Oregon.
 ALL RIGHTS RESERVED.
 
 Permission to use, copy, and distribute this software in
 its entirety for non-commercial purposes and without fee,
 is hereby granted, provided that the above copyright notice
 and this permission notice appear in all copies and their
 documentation.
 
 Software developers, consultants, or anyone else who wishes
 to use all or part of the software or its documentation for
 commercial purposes should contact the Technology Transfer
 Office at the University of Oregon to arrange a commercial
 license agreement.
 
 This software is provided "as is" without expressed or
 implied warranty of any kind.
 ********************************************************************/


#import <Foundation/Foundation.h>
#import <CoreData/CoreData.h>
#import "EPImporter.h"

void changeStore(NSPersistentStoreCoordinator *coordinator, NSURL *storeURL)
{
	// remove old store.
	NSError *error = nil;
	NSArray *oldStores = [coordinator persistentStores];
	if ([oldStores count] != 0) {
		[coordinator removePersistentStore:[oldStores objectAtIndex:0]
									 error:&error];
		if (error != nil) {
			NSLog(@"Cannot remove previous store.");
			exit(1);
		}
	}
	// add new store.
	NSPersistentStore *newStore = [coordinator addPersistentStoreWithType:NSSQLiteStoreType
															configuration:nil
																	  URL:storeURL
																  options:nil
																	error:&error];
	if (newStore == nil) {
		NSLog(@"Store Configuration Failure\n%@",
			  ([error localizedDescription] != nil) ?
			  [error localizedDescription] : @"Unknown Error");
		return;
	}
	
}

int main (int argc, const char * argv[]) {
	objc_startCollectorThread();
	
	// load model
	NSManagedObjectModel *mom = [VFUtil managedObjectModel];
	NSPersistentStoreCoordinator *coordinator =
	[[NSPersistentStoreCoordinator alloc] initWithManagedObjectModel: mom];
	
	NSManagedObjectContext *moc = [[NSManagedObjectContext alloc] init];
    [moc setPersistentStoreCoordinator: coordinator];
	[moc setUndoManager:nil];
	
	EPImporter *importer = [[EPImporter alloc] initWithMOC:moc];
	
	NSURL *argURL = [NSURL fileURLWithPath:[NSString stringWithUTF8String:argv[1]]];
	NSFileManager *fileManager = [[NSFileManager alloc] init];
	BOOL isDir;
	NSError *error;
	
	if ([fileManager fileExistsAtPath:[argURL path] isDirectory:&isDir]) {
		if (isDir) {
			NSArray *filePaths = [fileManager contentsOfDirectoryAtPath:[argURL path] error:NULL];
			// Import all gazedata file
			for (NSString *eachPath in filePaths) {
				if ([[eachPath pathExtension] isEqualToString:@"gazedata"]) {
					NSString *storePath = [[argURL path] stringByAppendingPathComponent:
										   [[eachPath stringByDeletingPathExtension] 
											 stringByAppendingString:@".vizfixsql"]];
					
					if ([fileManager fileExistsAtPath:storePath]) {
						[fileManager removeItemAtPath:storePath error:&error];
					}
					
					NSURL *storeURL = [NSURL fileURLWithPath:storePath];
					changeStore(coordinator, storeURL);
					
					[importer import:[NSURL fileURLWithPath:[[argURL path] stringByAppendingPathComponent:eachPath]]];
				}
			}
		} else {
			// Just one file to import.
			changeStore(coordinator, argURL);
			[importer import:argURL];
		}
	} else {
		printf("Error! %s does not exist.", [[argURL path] UTF8String]);
	}
		 
    return 0;
}
